@@ -3,9 +3,10 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.14';
+our $VERSION = '1.15';
 
 use Carp;
+use Fcntl qw(:flock);
 use File::Find::Rule;
 use File::Temp;
 
@@ -82,6 +83,8 @@ sub write {
     
     my $wfh = $self->_open($file, 'w');
 
+    flock $wfh, LOCK_EX;
+
     $recsep = defined $recsep ? $recsep : $self->{recsep};
 
     # is contents a fh?
@@ -102,6 +105,9 @@ sub write {
         }
     }
 
+    # the following allows unit tests to test the lock
+    sleep 1 if $ENV{TEST_WRITE_LOCK};
+
     close $wfh;
     $self->{is_read} = 0;
     
@@ -415,7 +421,9 @@ __END__
 
 File::Edit::Portable - Read and write files while keeping the original line-endings intact, no matter the platform.
 
-=cut
+=for html
+<a href="http://travis-ci.org/stevieb9/file-edit-portable"><img src="https://secure.travis-ci.org/stevieb9/file-edit-portable.png"/>
+<a href='https://coveralls.io/github/stevieb9/file-edit-portable?branch=master'><img src='https://coveralls.io/repos/stevieb9/file-edit-portable/badge.svg?branch=master&service=github' alt='Coverage Status' /></a>
 
 =head1 SYNOPSIS
 
@@ -576,12 +584,7 @@ automatically be notified of progress on your bug as I make changes.
 
 L<https://github.com/stevieb9/file-edit-portable>
 
-=head1 BUILD RESULTS
-
-=begin html
-<a href="http://travis-ci.org/stevieb9/file-edit-portable"><img src="https://secure.travis-ci.org/stevieb9/file-edit-portable.png"/>
-<a href='https://coveralls.io/github/stevieb9/file-edit-portable?branch=master'><img src='https://coveralls.io/repos/stevieb9/file-edit-portable/badge.svg?branch=master&service=github' alt='Coverage Status' /></a>
-=end html
+=head1 BUILD RESULTS (THIS VERSION)
 
 CPAN Testers: L<http://matrix.cpantesters.org/?dist=File-Edit-Portable>
 
@@ -591,23 +594,6 @@ You can find documentation for this module with the perldoc command.
 
     perldoc File::Edit::Portable
 
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker (report bugs here)
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=File-Edit-Portable>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/File-Edit-Portable/>
-
-=back
-
-
-
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2016 Steve Bertrand.
